@@ -1,12 +1,11 @@
 package Test::Compile;
 
-use 5.6.2;
 use warnings;
 use strict;
 
+use version; our $VERSION = qv("v1.3.0");
 use UNIVERSAL::require;
 use Test::Compile::Internal;
-use version; our $VERSION = qv("v1.1.0");
 
 my $Test = Test::Compile::Internal->new();
 
@@ -22,7 +21,7 @@ Test::Compile - Check whether Perl files compile correctly.
     $test->all_files_ok();
     $test->done_testing();
 
-    # The procedural way
+    # The procedural way (deprecated)
     use Test::Compile;
     all_pm_files_ok();
 
@@ -85,7 +84,7 @@ sub new {
 Checks all the perl files it can find for compilation errors.
 
 If C<@dirs> is defined then it is taken as an array of directories to
-be searched for perl files, otherwise it searches some default locatioons
+be searched for perl files, otherwise it searches some default locations
 - see L</all_pm_files()> and L</all_pl_files()>.
 
 =item C<all_pm_files(@dirs)>
@@ -101,9 +100,10 @@ sorted, you'll have to sort them yourself.
 
 =item C<all_pl_files(@dirs)>
 
-Returns a list of all the perl script files - that is, any files ending in F<.pl>
-or files with no extension in C<@dirs> and in directories below. If
-C<@dirs> is undefined, it searches F<script> if F<script> exists, or else
+Returns a list of all the perl script files - that is, any files in C<@dirs> that
+either have a F<.pl> extension, or have no extension and have a perl shebang line.
+
+If C<@dirs> is undefined, it searches F<script> if F<script> exists, or else
 F<bin> if F<bin> exists.
 
 Skips any files in C<CVS> or C<.svn> directories.
@@ -128,7 +128,7 @@ Verbose is set on by default.
 
 =back
 
-=head2 TEST METHODS
+=head2 Test Methods
 
 C<Test::Compile::Internal> encapsulates a C<Test::Builder> object, and provides
 access to some of its methods.
@@ -139,7 +139,7 @@ access to some of its methods.
 
 Declares that you are done testing, no more tests will be run after this point.
 
-=item C<ok($test,$name)>
+=item C<ok($test, $name)>
 
 Your basic test. Pass if C<$test> is true, fail if C<$test> is false. Just
 like C<Test::Simple>'s C<ok()>.
@@ -175,6 +175,15 @@ Skips all the tests, using the given C<$reason>. Exits immediately with 0.
 
 =head1 FUNCTIONS
 
+The use of the following functions is deprecated and strongly discouraged.
+
+They are automatically exported to your namespace,  which is
+no longer considered best practise.  At some stage in the future, this will
+stop and you'll have to import them explicitly.
+
+Even then, you really should use the object oriented methods as they provide
+a more consistent interface.
+
 =over 4
 
 =item C<all_pm_files_ok(@files)>
@@ -254,7 +263,7 @@ sub all_pl_files_ok {
     $ok;
 }
 
-=item C<pm_file_ok($filename,$testname)>
+=item C<pm_file_ok($filename, $testname)>
 
 C<pm_file_ok()> will okay the test if $filename compiles as a perl module.
 
@@ -264,7 +273,7 @@ $filename>.
 
 =cut
 sub pm_file_ok {
-    my ($file,$name) = @_;
+    my ($file, $name) = @_;
 
     $name ||= "Compile test for $file";
 
@@ -275,7 +284,7 @@ sub pm_file_ok {
     return $ok;
 }
 
-=item C<pl_file_ok($filename,$testname)>
+=item C<pl_file_ok($filename, $testname)>
 
 C<pl_file_ok()> will okay the test if $filename compiles as a perl script. You
 need to give the path to the script relative to this distribution's base
@@ -288,7 +297,7 @@ $filename>.
 =cut
 
 sub pl_file_ok {
-    my ($file,$name) = @_;
+    my ($file, $name) = @_;
 
     $name ||= "Compile test for $file";
 
@@ -331,10 +340,13 @@ sub all_pm_files {
 
 =item C<all_pl_files(@dirs)>
 
-Returns a list of all the perl script files - that is, files ending in F<.pl>
-or with no extension. Directory arguments are searched recursively . If
-I<@dirs> is undefined, it defaults to F<script> if F<script> exists, or else
-F<bin> if F<bin> exists. Skips any files in C<CVS> or C<.svn> directories.
+Returns a list of all the perl script files - that is, any files in C<@dirs> that
+either have a F<.pl> extension, or have no extension and have a perl shebang line.
+
+If C<@dirs> is undefined, it searches F<script> if F<script> exists, or else
+F<bin> if F<bin> exists.
+
+Skips any files in C<CVS> or C<.svn> directories.
 
 The order of the files returned is machine-dependent. If you want them
 sorted, you'll have to sort them yourself.
@@ -360,7 +372,7 @@ Evan Giles, C<< <egiles@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2014 by the authors.
+Copyright 2007-2015 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -370,7 +382,7 @@ it under the same terms as Perl itself.
 L<Test::Compile::Internal> provides the object oriented interface to (and the
 inner workings for) the Test::Compile functionality.
 
-L<Test::Strict> proveds functions to ensure your perl files comnpile, with
+L<Test::Strict> provides functions to ensure your perl files compile, with
 added bonus that it will check you have used strict in all your files.
 L<Test::LoadAllModules> just handles modules, not script files, but has more
 fine-grained control.
